PCB Environment: NavImage< chan_t > Class Template Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions
NavImage< chan_t > Class Template Reference

`#include <NavImage.hpp>`

Inheritance diagram for NavImage< chan_t >:

## Public Member Functions
| NavImage (const NavImage< chan_t > &)
| NavImage (const NavGrid &)
| NavImage (uint w, uint h, const Bbox_2 &, uint numLayers)
size_t | sizeInBytes () const
int | checkFit (const UniformGrid25 &) const
NavPixel< chan_t > & | at (uint i)
NavPixel< chan_t > & | at (uint x, uint y)
const NavPixel< chan_t > & | at (uint x, uint y) const
void | draw1To1 (const NavGrid &)
| WARNING: draw1To1() does not set via channel.
void | drawDownscale (const NavGrid &)
void | drawStatic (const PCBoard &)
void | drawDynamic (const PCBoard &)
void | drawRatsNest (const PCBoard &, const bool all)
void | draw (const Pin &)
void | draw (const Connection &)
void | draw (const Track &)
void | drawRatsNest (const Connection &)
PyObject * | movePy ()
Public Member Functions inherited from UniformGrid25
| UniformGrid25 (Real edgeLen)
IVector_3 | getSize () const
uint | getSize (uint d) const
const Bbox_2 & | getBbox () const
Real | XCoord (int x) const
Real | YCoord (int y) const
Point_2 | Coords (const IPoint_2 &v) const
Point_2 | Coords (int x, int y) const
Point_25 | Coords (const IPoint_3 &v) const
Point_25 | Coords (int x, int y, uint z) const
Vector_2 | MidPointOffset () const
Real | MidPointX (int x) const
Real | MidPointY (int y) const
Point_2 | MidPoint (const IPoint_2 &v) const
Point_2 | MidPoint (int x, int y) const
Point_25 | MidPoint (const IPoint_3 &v) const
IVector_2 | HIndices (const Point_2 &v) const
int | XIndex (Real x, Real ex=0.0) const
int | YIndex (Real y, Real ey=0.0) const
uint | XIndexBounded (Real x, Real ex=0.0) const
uint | YIndexBounded (Real y, Real ey=0.0) const
uint | LinearIndex (uint z, uint y, uint x) const
uint | LinearIndex (const Point_25 &v) const
IBox_3 | getBox (const Bbox_2 &, uint z0=0, uint z1=std::numeric_limits< uint >::max()) const
Real | XfIndex (Real x, Real ex=0.0) const
Real | YfIndex (Real y, Real ey=0.0) const
uint | getNumPoints2D () const
uint | getNumPoints3D () const
bool | inside (const IPoint_3 &v) const
bool | inside (uint x, uint y, uint z) const
Point_25 | snapToMidPoint (const Point_25 &) const

## Static Public Member Functions
static chan_t | getLayerMCoverage (uint d)

## Additional Inherited Members
Data Fields inherited from UniformGrid25
const Real | EdgeLen
const Real | EdgeLen05
const Real | EdgeLenRcp
Protected Member Functions inherited from UniformGrid25
void | calcNumPoints3D ()
Protected Attributes inherited from UniformGrid25
Bbox_2 | mBbox
uint | mSize [3]
uint | mStrideZ
uint | mStrideY
uint | mNumPoints3D

## Detailed Description

template<typename chan_t>
class NavImage< chan_t >

This is usually a scaled down and/or cropped version of the NavGrid. We use a 2D grid with layers encoded in the NavPixel's fixed number of channels.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavImage.hpp